@@ -34,7 +34,9 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
+import javax.el.ExpressionFactory;
 import javax.faces.FacesException;
+import javax.faces.context.FacesContext;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -43,7 +45,7 @@ import org.apache.commons.logging.LogFactory;
 /**
  * @author Manfred Geiler (latest modification by $Author: lu4242 $)
  * @author Anton Koinov
- * @version $Revision: 1031358 $ $Date: 2010-11-04 19:00:39 -0500 (Thu, 04 Nov 2010) $
+ * @version $Revision: 1004421 $ $Date: 2010-10-04 15:45:07 -0500 (Mon, 04 Oct 2010) $
  */
 public final class ClassUtils
 {
@@ -325,7 +327,7 @@ public final class ClassUtils
             throw new FacesException(e);
         }
     }
-    /*
+
     public static Object convertToType(Object value, Class desiredClass)
     {
         if (value == null) return null;
@@ -342,7 +344,7 @@ public final class ClassUtils
             log.error(message, e);
             throw new FacesException(message, e);
         }
-    }*/
+    }
 
     /**
      * Gets the ClassLoader associated with the current thread.  Returns the class loader associated with
